@@ -28,7 +28,7 @@ namespace acommon {
   // an error.  Extra accepted keys can be added with the set_extra 
   // method.
 
-  // Keys taged with KEYINFO_UTF8 are expected to be in UTF-8 format.
+  // Keys tagged with KEYINFO_UTF8 are expected to be in UTF-8 format.
   // Keys with file/dir names may contain 8-bit characters and must
   //   remain untranslated
   // All other keys are expected to only contain ASCII characters.
@@ -72,7 +72,7 @@ namespace acommon {
   // -- setting a boolean value to an empty string is the same as setting 
   //    it to true
   //
-  // lset - sets a list, items seperated by ':'
+  // lset - sets a list, items separated by ':'
   // rem, remove - removes item from a list
   // add - add an item to a list
   // clear - removes all items from a list
@@ -95,9 +95,10 @@ namespace acommon {
       unsigned line_num;
       Action action;
       bool need_conv;
+      bool secure; // if the value was set in a secure content
       short place_holder;
       Entry() : line_num(0), action(NoOp), 
-                need_conv(false), place_holder(-1) {}
+                need_conv(false), secure(false), place_holder(-1) {}
     };
 
   private:
@@ -137,7 +138,7 @@ namespace acommon {
   public:
 
     // the first
-    // if the second parameter is set than flaged options will be
+    // if the second parameter is set than flagged options will be
     // converted to utf-8 if needed
     PosibErr<void> commit_all(Vector<int> * = 0, const char * codeset = 0);
 
@@ -148,24 +149,24 @@ namespace acommon {
 
     PosibErr<void> merge(const Config & other);
 
-    void lang_config_merge(const Config & other,
-                           int which, ParmStr codeset);
+    PosibErr<void> lang_config_merge(const Config & other,
+                                     int which, ParmStr codeset);
 
     bool settings_read_in() {return settings_read_in_;}
 
     PosibErr<void> set_committed_state(bool val);
 
     const Entry * lookup(const char * key) const;
-    void lookup_list(const KeyInfo * ki, MutableContainer & m, 
-                     bool include_default) const;
+    PosibErr<void> lookup_list(const KeyInfo * ki, MutableContainer & m, 
+                               bool include_default) const;
 
     String temp_str;
 
     PosibErr<const ConfigModule *> (* load_filter_hook)(Config * config, ParmStr value);
     Notifier * filter_mode_notifier;
 
-    Vector<ConfigModule>      filter_modules;
-    Vector<Cacheable *> filter_modules_ptrs;
+    Vector<ConfigModule> filter_modules;
+    Vector<Cacheable *>  filter_modules_ptrs;
 
     Config(ParmStr name,
 	   const KeyInfo * mainbegin, 
@@ -207,7 +208,15 @@ namespace acommon {
 
     PosibErr<String> retrieve(ParmStr key) const;
 
-    // will also retrive a list, with one value per line
+    struct Value {
+      String val;
+      bool secure;
+      Value() {}
+      Value(const String & v, bool s = false) : val(v), secure(s) {}
+    };
+    PosibErr<Value> retrieve_value(ParmStr key) const;
+
+    // will also retrieve a list, with one value per line
     PosibErr<String> retrieve_any(ParmStr key) const;
   
     bool have (ParmStr key) const;
