@@ -7,6 +7,8 @@
 #ifndef ASPELL_CONVERT__HPP
 #define ASPELL_CONVERT__HPP
 
+#include "settings.h"
+
 #include "string.hpp"
 #include "posib_err.hpp"
 #include "char_vector.hpp"
@@ -21,12 +23,22 @@ namespace acommon {
   class OStream;
   class Config;
 
+  struct ConvKey {
+    ParmString val;
+    bool allow_ucs;
+    ConvKey() : val(), allow_ucs() {}
+    template <typename T>
+    ConvKey(const T & v, bool a = false) : val(v), allow_ucs(a) {}
+  };
+
   struct ConvBase : public Cacheable {
     typedef const Config CacheConfig;
-    typedef const char * CacheKey;
+    typedef ConvKey CacheKey;
     String key;
-    bool cache_key_eq(const char * l) const  {return key == l;}
-    ConvBase() {}
+    int type_width; // type width in bytes
+    bool is_ucs() const {return type_width != 1;}
+    bool cache_key_eq(CacheKey k) const  {return k.allow_ucs ? key == k.val : key == k.val && !is_ucs();}
+    ConvBase() : type_width(1) {}
   private:
     ConvBase(const ConvBase &);
     void operator=(const ConvBase &);
@@ -38,7 +50,7 @@ namespace acommon {
 			FilterCharVector & out) const = 0;
     virtual PosibErr<void> decode_ec(const char * in, int size,
                                      FilterCharVector & out, ParmStr orig) const = 0;
-    static PosibErr<Decode *> get_new(const String &, const Config *);
+    static PosibErr<Decode *> get_new(const ConvKey &, const Config *);
     virtual ~Decode() {}
   };
   struct Encode : public ConvBase {
@@ -52,10 +64,12 @@ namespace acommon {
     // may convert inplace
     virtual bool encode(FilterChar * & in, FilterChar * & stop, 
                         FilterCharVector & buf) const {return false;}
-    static PosibErr<Encode *> get_new(const String &, const Config *);
+    static PosibErr<Encode *> get_new(const ConvKey &, const Config *);
     virtual ~Encode() {}
   };
   struct DirectConv { // convert directly from in_code to out_code.
+    int type_width; // type width in bytes
+    DirectConv() : type_width(1) {}
     // should not take ownership of decode and encode.
     // decode and encode guaranteed to stick around for the life
     // of the object.
@@ -119,13 +133,16 @@ namespace acommon {
     // this class in any way.
     Filter filter;
 
-    PosibErr<void> init(const Config &, ParmStr in, ParmStr out);
-    PosibErr<void> init_norm_to(const Config &, ParmStr in, ParmStr out);
-    PosibErr<void> init_norm_from(const Config &, ParmStr in, ParmStr out);
+    PosibErr<void> init(const Config &, const ConvKey & in, const ConvKey & out);
+    PosibErr<void> init_norm_to(const Config &, const ConvKey & in, const ConvKey & out);
+    PosibErr<void> init_norm_from(const Config &, const ConvKey & in, const ConvKey & out);
     
     const char * in_code() const   {return decode_->key.c_str();}
     const char * out_code() const  {return encode_->key.c_str();}
 
+    int in_type_width() const {return decode_->type_width;}
+    int out_type_width() const {return encode_->type_width;}
+
     void append_null(CharVector & out) const
     {
       const char nul[4] = {0,0,0,0}; // 4 should be enough
@@ -191,6 +208,10 @@ namespace acommon {
       }
     }
 
+    void convert(const void * in, int size, CharVector & out) {
+      convert(static_cast<const char *>(in), size, out);
+    }
+
     void generic_convert(const char * in, int size, CharVector & out);
     
   };
@@ -205,19 +226,19 @@ namespace acommon {
   enum Normalize {NormNone, NormFrom, NormTo};
 
   PosibErr<Convert *> internal_new_convert(const Config & c, 
-                                           ParmString in, ParmString out,
+                                           ConvKey in, ConvKey out,
                                            bool if_needed,
                                            Normalize n);
   
   static inline PosibErr<Convert *> new_convert(const Config & c,
-                                                ParmStr in, ParmStr out,
+                                                const ConvKey & in, const ConvKey & out,
                                                 Normalize n)
   {
     return internal_new_convert(c,in,out,false,n);
   }
   
   static inline PosibErr<Convert *> new_convert_if_needed(const Config & c,
-                                                          ParmStr in, ParmStr out,
+                                                          const ConvKey & in, const ConvKey & out,
                                                           Normalize n)
   {
     return internal_new_convert(c,in,out,true,n);
@@ -227,7 +248,7 @@ namespace acommon {
     Convert * ptr;
     ConvObj(Convert * c = 0) : ptr(c) {}
     ~ConvObj() {delete ptr;}
-    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
+    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
     {
       delete ptr;
       ptr = 0;
@@ -251,7 +272,7 @@ namespace acommon {
     ConvP(const ConvObj & c) : conv(c.ptr) {}
     ConvP(const ConvP & c) : conv(c.conv) {}
     void operator=(const ConvP & c) { conv = c.conv; }
-    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, 
+    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, 
                          Normalize norm)
     {
       delete conv;
@@ -322,7 +343,7 @@ namespace acommon {
   {
     ConvObj conv_obj;
     Conv(Convert * c = 0) : ConvP(c), conv_obj(c) {}
-    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
+    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
     {
       RET_ON_ERR(conv_obj.setup(c,from,to,norm));
       conv = conv_obj.ptr;
@@ -339,7 +360,7 @@ namespace acommon {
     ConvECP(const ConvObj & c) : conv(c.ptr) {}
     ConvECP(const ConvECP & c) : conv(c.conv) {}
     void operator=(const ConvECP & c) { conv = c.conv; }
-    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
+    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
     {
       delete conv;
       conv = 0;
@@ -394,7 +415,7 @@ namespace acommon {
   {
     ConvObj conv_obj;
     ConvEC(Convert * c = 0) : ConvECP(c), conv_obj(c) {}
-    PosibErr<void> setup(const Config & c, ParmStr from, ParmStr to, Normalize norm)
+    PosibErr<void> setup(const Config & c, const ConvKey & from, const ConvKey & to, Normalize norm)
     {
       RET_ON_ERR(conv_obj.setup(c,from,to,norm));
       conv = conv_obj.ptr;
@@ -412,6 +433,30 @@ namespace acommon {
       return operator()(str, str + byte_size);}
   };
 
+#ifdef SLOPPY_NULL_TERM_STRINGS
+  static const bool sloppy_null_term_strings = true;
+#else
+  static const bool sloppy_null_term_strings = false;
+#endif
+  
+  PosibErr<void> unsupported_null_term_wide_string_err_(const char * func);
+  void unsupported_null_term_wide_string_abort_(const char * func);
+    
+  static inline PosibErr<int> get_correct_size(const char * func, int conv_type_width, int size) {
+    if (sloppy_null_term_strings && size <= -1)
+      return -conv_type_width;
+    if (size <= -1 && -conv_type_width != size)
+      return unsupported_null_term_wide_string_err_(func);
+    return size;
+  }
+  static inline int get_correct_size(const char * func, int conv_type_width, int size, int type_width) {
+    if ((sloppy_null_term_strings || type_width <= -1) && size <= -1)
+      return -conv_type_width;
+    if (size <= -1 && conv_type_width != type_width)
+      unsupported_null_term_wide_string_abort_(func);
+    return size;
+  }
+
 }
 
 #endif
