@@ -20,6 +20,28 @@ using namespace acommon;
 
 namespace acommon {
   struct CheckInfo;
+
+  struct ConfigConvKey : public ConvKey {
+    Config::Value config_val;
+    template <typename T>
+    ConfigConvKey(const T & v) : config_val(v) {
+      val = config_val.val;
+      allow_ucs = config_val.secure;
+    }
+    ConfigConvKey & operator=(const ConfigConvKey & other) {
+      config_val = other.config_val; 
+      val = config_val.val;
+      allow_ucs = config_val.secure;
+      return *this;
+    }
+    void fix_encoding_str() {
+      String buf;
+      ::fix_encoding_str(val, buf);
+      config_val.val.swap(buf);
+      val = config_val.val;
+    }
+  private:
+  };
 }
 
 namespace aspeller {
@@ -58,6 +80,28 @@ namespace aspeller {
 
   //
 
+  //
+
+  struct CompoundWord {
+    const char * word;
+    const char * sep;
+    const char * rest;
+    const char * end;
+    bool empty() const {return word == end;}
+    bool single() const {return rest == end;}
+    unsigned word_len() const {return sep - word;}
+    unsigned rest_offset() const {return rest - word;}
+    unsigned rest_len() const {return end - rest;}
+    CompoundWord()
+      : word(), sep(), rest(), end() {}
+    CompoundWord(const char * a, const char * b)
+      : word(a), sep(b), rest(b), end(b) {}
+    CompoundWord(const char * a, const char * b, const char * c)
+      : word(a), sep(b), rest(b), end(c) {}
+    CompoundWord(const char * a, const char * b, const char * c, const char * d)
+      : word(a), sep(b), rest(c), end(d) {}
+  };
+
   enum StoreAs {Stripped, Lower};
 
   class Language : public Cacheable {
@@ -130,7 +174,7 @@ namespace aspeller {
 
     Language() {}
     PosibErr<void> setup(const String & lang, const Config * config);
-    void set_lang_defaults(Config & config) const;
+    PosibErr<void> set_lang_defaults(Config & config) const;
 
     const char * data_dir() const {return dir_.c_str();}
     const char * name() const {return name_.c_str();}
@@ -336,6 +380,12 @@ namespace aspeller {
     const char * fix_case(CasePattern case_pattern, 
                           const char * str, String & buf) const;
 
+    //
+    //
+    //
+
+    CompoundWord split_word(const char * str, unsigned size, bool camel_case) const;
+
     //
     // for cache
     //
@@ -438,6 +488,13 @@ namespace aspeller {
                      OStream * log);
     // init may set "norm-strict" to true which is why it is not const
     PosibErr<void> init (Config & config);
+    // init_plain initialized the iterator to read in a plain word
+    // list without any affix flags, for simplicity it will expect the
+    // input to be utf-8.  It will also assume clean the words unless
+    // the `clean-words` option is explicitly specified.  Like init it
+    // may set "norm-strict" to true which is why it is not const
+    PosibErr<void> init_plain (Config & config);
+    const Value & operator*() const {return val;}
     const Value * operator-> () const {return &val;}
     PosibErr<bool> adv();
   private:
@@ -456,7 +513,6 @@ namespace aspeller {
     const char * orig;
     char * str;
     char * str_end;
-    char brk[3];
     CleanAffix clean_affix;
   };
 
@@ -464,6 +520,7 @@ namespace aspeller {
 
   String get_clean_chars(const Language & l);
   
+  PosibErr<void> check_if_sane(const Language & l, ParmStr word);
   PosibErr<void> check_if_valid(const Language & l, ParmStr word);
   PosibErr<void> validate_affix(const Language & l, ParmStr word, ParmStr aff);
 
